@@ -24,30 +24,30 @@
 #include <assert.h>
 
 #include <kbookmarkmanager.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kpropertiesdialog.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kstatusbar.h>
-#include <kaccel.h>
-#include <kio/netaccess.h>
-#include <kfiledialog.h>
-#include <kconfig.h>
+#include <tdeaccel.h>
+#include <tdeio/netaccess.h>
+#include <tdefiledialog.h>
+#include <tdeconfig.h>
 #include <kurl.h>
 #include <kurldrag.h>
-#include <kstdaccel.h>
-#include <kaction.h>
+#include <tdestdaccel.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
-#include <kactionclasses.h>
-#include <kpopupmenu.h>
-#include <kio/renamedlg.h>
+#include <tdeactionclasses.h>
+#include <tdepopupmenu.h>
+#include <tdeio/renamedlg.h>
 #include <kinputdialog.h>
 #include <kshell.h>
 #include <kdesktopfile.h>
 #include <kstandarddirs.h>
 #include <kprotocolinfo.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kservice.h>
 #include <kstandarddirs.h>
 #include <krun.h>
@@ -104,7 +104,7 @@ void Dolphin::setActiveView(DolphinView* view)
 void Dolphin::dropURLs(const KURL::List& urls,
                        const KURL& destination)
 {
-    const ButtonState keyboardState = KApplication::keyboardMouseState();
+    const ButtonState keyboardState = TDEApplication::keyboardMouseState();
     const bool shiftPressed = (keyboardState & ShiftButton) > 0;
     const bool controlPressed = (keyboardState & ControlButton) > 0;
 
@@ -123,13 +123,13 @@ void Dolphin::dropURLs(const KURL::List& urls,
     }
     else {
         // no shortcut is used, hence open a popup menu
-        KPopupMenu popup(this);
+        TDEPopupMenu popup(this);
 
         popup.insertItem(SmallIcon("goto"), i18n("&Move Here") + "\t" + KKey::modFlagLabel(KKey::SHIFT), 0);
-        popup.insertItem(SmallIcon("editcopy"), i18n( "&Copy Here" ) + "\t" + KKey::modFlagLabel(KKey::CTRL), 1);
+        popup.insertItem(SmallIcon("edit-copy"), i18n( "&Copy Here" ) + "\t" + KKey::modFlagLabel(KKey::CTRL), 1);
         popup.insertItem(i18n("&Link Here") + "\t" + KKey::modFlagLabel((KKey::ModFlag)(KKey::CTRL|KKey::SHIFT)), 2);
         popup.insertSeparator();
-        popup.insertItem(SmallIcon("stop"), i18n("Cancel"), 3);
+        popup.insertItem(SmallIcon("process-stop"), i18n("Cancel"), 3);
         popup.setAccel(i18n("Escape"), 3);
 
         selectedIndex = popup.exec(TQCursor::pos());
@@ -156,7 +156,7 @@ void Dolphin::dropURLs(const KURL::List& urls,
 
         case 2: {
             // 'Link Here' has been selected
-            KIO::Job* job = KIO::link(urls, destination);
+            TDEIO::Job* job = TDEIO::link(urls, destination);
             addPendingUndoJob(job, DolphinCommand::Link, urls, destination);
             break;
         }
@@ -232,21 +232,21 @@ void Dolphin::slotViewModeChanged()
 
 void Dolphin::slotShowHiddenFilesChanged()
 {
-    KToggleAction* showHiddenFilesAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_hidden_files"));
+    TDEToggleAction* showHiddenFilesAction =
+        static_cast<TDEToggleAction*>(actionCollection()->action("show_hidden_files"));
     showHiddenFilesAction->setChecked(m_activeView->isShowHiddenFilesEnabled());
 }
 
 void Dolphin::slotShowFilterBarChanged()
 {
-    KToggleAction* showFilterBarAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_filter_bar"));
+    TDEToggleAction* showFilterBarAction =
+        static_cast<TDEToggleAction*>(actionCollection()->action("show_filter_bar"));
     showFilterBarAction->setChecked(m_activeView->isFilterBarVisible());
 }
 
 void Dolphin::slotSortingChanged(DolphinView::Sorting sorting)
 {
-    KAction* action = 0;
+    TDEAction* action = 0;
     switch (sorting) {
         case DolphinView::SortByName:
             action = actionCollection()->action("by_name");
@@ -262,14 +262,14 @@ void Dolphin::slotSortingChanged(DolphinView::Sorting sorting)
     }
 
     if (action != 0) {
-        KToggleAction* toggleAction = static_cast<KToggleAction*>(action);
+        TDEToggleAction* toggleAction = static_cast<TDEToggleAction*>(action);
         toggleAction->setChecked(true);
     }
 }
 
 void Dolphin::slotSortOrderChanged(TQt::SortOrder order)
 {
-    KToggleAction* descending = static_cast<KToggleAction*>(actionCollection()->action("descending"));
+    TDEToggleAction* descending = static_cast<TDEToggleAction*>(actionCollection()->action("descending"));
     const bool sortDescending = (order == TQt::Descending);
     descending->setChecked(sortDescending);
 }
@@ -284,7 +284,7 @@ void Dolphin::slotSelectionChanged()
         selectedURLsCount += m_view[SecondaryIdx]->selectedURLs().count();
     }
 
-    KAction* compareFilesAction = actionCollection()->action("compare_files");
+    TDEAction* compareFilesAction = actionCollection()->action("compare_files");
     compareFilesAction->setEnabled(selectedURLsCount == 2);
 
     m_activeView->updateStatusBar();
@@ -294,7 +294,7 @@ void Dolphin::slotSelectionChanged()
 
 void Dolphin::closeEvent(TQCloseEvent* event)
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("General");
     config->writeEntry("First Run", false);
 
@@ -317,10 +317,10 @@ void Dolphin::closeEvent(TQCloseEvent* event)
     settings.save();
 
     config->sync();
-    KMainWindow::closeEvent(event);
+    TDEMainWindow::closeEvent(event);
 }
 
-void Dolphin::saveProperties(KConfig* config)
+void Dolphin::saveProperties(TDEConfig* config)
 {
     config->setGroup("Primary view");
     config->writeEntry("URL", m_view[PrimaryIdx]->url().url());
@@ -332,7 +332,7 @@ void Dolphin::saveProperties(KConfig* config)
     }
 }
 
-void Dolphin::readProperties(KConfig* config)
+void Dolphin::readProperties(TDEConfig* config)
 {
     config->setGroup("Primary view");
     m_view[PrimaryIdx]->setURL(config->readEntry("URL"));
@@ -365,7 +365,7 @@ void Dolphin::createFolder()
 
     TQString name(i18n("New Folder"));
     if (baseURL.isLocalFile() && TQFileInfo(baseURL.path(+1) + name).exists()) {
-        name = KIO::RenameDlg::suggestName(baseURL, i18n("New Folder"));
+        name = TDEIO::RenameDlg::suggestName(baseURL, i18n("New Folder"));
     }
 
     bool ok = false;
@@ -387,11 +387,11 @@ void Dolphin::createFolder()
         url.setPath(KShell::tildeExpand(name));
     }
     else {
-        name = KIO::encodeFileName(name);
+        name = TDEIO::encodeFileName(name);
         url = baseURL;
         url.addPath(name);
     }
-    ok = KIO::NetAccess::mkdir(url, this);
+    ok = TDEIO::NetAccess::mkdir(url, this);
 
     // TODO: provide message type hint
     if (ok) {
@@ -404,7 +404,7 @@ void Dolphin::createFolder()
     else {
         // Creating of the folder has been failed. Check whether the creating
         // has been failed because a folder with the same name exists...
-        if (KIO::NetAccess::exists(url, true, this)) {
+        if (TDEIO::NetAccess::exists(url, true, this)) {
             statusBar->setMessage(i18n("A folder named %1 already exists.").arg(url.path()),
                                   DolphinStatusBar::Error);
         }
@@ -468,9 +468,9 @@ void Dolphin::createFile()
     // a unique file name (e. g. "HTML File" will be replaced by "HTML File_1").
     const KURL viewURL(m_activeView->url());
     const bool fileExists = viewURL.isLocalFile() &&
-                            TQFileInfo(viewURL.path(+1) + KIO::encodeFileName(name)).exists();
+                            TQFileInfo(viewURL.path(+1) + TDEIO::encodeFileName(name)).exists();
     if (fileExists) {
-        name = KIO::RenameDlg::suggestName(viewURL, name);
+        name = TDEIO::RenameDlg::suggestName(viewURL, name);
     }
 
     // let the user change the suggested file name
@@ -487,9 +487,9 @@ void Dolphin::createFile()
 
     // before copying the template to the destination path check whether a file
     // with the given name already exists
-    const TQString destPath(viewURL.prettyURL() + "/" + KIO::encodeFileName(name));
+    const TQString destPath(viewURL.prettyURL() + "/" + TDEIO::encodeFileName(name));
     const KURL destURL(destPath);
-    if (KIO::NetAccess::exists(destURL, false, this)) {
+    if (TDEIO::NetAccess::exists(destURL, false, this)) {
         statusBar->setMessage(i18n("A file named %1 already exists.").arg(name),
                               DolphinStatusBar::Error);
         return;
@@ -497,9 +497,9 @@ void Dolphin::createFile()
 
     // copy the template to the destination path
     const KURL sourceURL(sourcePath);
-    KIO::CopyJob* job = KIO::copyAs(sourceURL, destURL);
+    TDEIO::CopyJob* job = TDEIO::copyAs(sourceURL, destURL);
     job->setDefaultPermissions(true);
-    if (KIO::NetAccess::synchronousRun(job, this)) {
+    if (TDEIO::NetAccess::synchronousRun(job, this)) {
         statusBar->setMessage(i18n("Created file %1.").arg(name),
                               DolphinStatusBar::OperationCompleted);
 
@@ -525,7 +525,7 @@ void Dolphin::moveToTrash()
 {
     clearStatusBar();
     KURL::List selectedURLs = m_activeView->selectedURLs();
-    KIO::Job* job = KIO::trash(selectedURLs);
+    TDEIO::Job* job = TDEIO::trash(selectedURLs);
     addPendingUndoJob(job, DolphinCommand::Trash, selectedURLs, m_activeView->url());
 }
 
@@ -549,14 +549,14 @@ void Dolphin::deleteItems()
     const bool del = KMessageBox::warningContinueCancel(this,
                                                         text,
                                                         TQString(),
-                                                        KGuiItem(i18n("Delete"), SmallIcon("editdelete"))
+                                                        KGuiItem(i18n("Delete"), SmallIcon("edit-delete"))
                                                        ) == KMessageBox::Continue;
     if (del) {
-        KIO::Job* job = KIO::del(list);
-        connect(job, TQT_SIGNAL(result(KIO::Job*)),
-                this, TQT_SLOT(slotHandleJobError(KIO::Job*)));
-        connect(job, TQT_SIGNAL(result(KIO::Job*)),
-                this, TQT_SLOT(slotDeleteFileFinished(KIO::Job*)));
+        TDEIO::Job* job = TDEIO::del(list);
+        connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
+                this, TQT_SLOT(slotHandleJobError(TDEIO::Job*)));
+        connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
+                this, TQT_SLOT(slotDeleteFileFinished(TDEIO::Job*)));
     }
 }
 
@@ -583,7 +583,7 @@ void Dolphin::quit()
     close();
 }
 
-void Dolphin::slotHandleJobError(KIO::Job* job)
+void Dolphin::slotHandleJobError(TDEIO::Job* job)
 {
     if (job->error() != 0) {
         m_activeView->statusBar()->setMessage(job->errorString(),
@@ -591,7 +591,7 @@ void Dolphin::slotHandleJobError(KIO::Job* job)
     }
 }
 
-void Dolphin::slotDeleteFileFinished(KIO::Job* job)
+void Dolphin::slotDeleteFileFinished(TDEIO::Job* job)
 {
     if (job->error() == 0) {
         m_activeView->statusBar()->setMessage(i18n("Delete operation completed."),
@@ -607,7 +607,7 @@ void Dolphin::slotDeleteFileFinished(KIO::Job* job)
 
 void Dolphin::slotUndoAvailable(bool available)
 {
-    KAction* undoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Undo));
+    TDEAction* undoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Undo));
     if (undoAction != 0) {
         undoAction->setEnabled(available);
     }
@@ -615,7 +615,7 @@ void Dolphin::slotUndoAvailable(bool available)
 
 void Dolphin::slotUndoTextChanged(const TQString& text)
 {
-    KAction* undoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Undo));
+    TDEAction* undoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Undo));
     if (undoAction != 0) {
         undoAction->setText(text);
     }
@@ -623,7 +623,7 @@ void Dolphin::slotUndoTextChanged(const TQString& text)
 
 void Dolphin::slotRedoAvailable(bool available)
 {
-    KAction* redoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Redo));
+    TDEAction* redoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Redo));
     if (redoAction != 0) {
         redoAction->setEnabled(available);
     }
@@ -631,7 +631,7 @@ void Dolphin::slotRedoAvailable(bool available)
 
 void Dolphin::slotRedoTextChanged(const TQString& text)
 {
-    KAction* redoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Redo));
+    TDEAction* redoAction = actionCollection()->action(KStdAction::stdName(KStdAction::Redo));
     if (redoAction != 0) {
         redoAction->setText(text);
     }
@@ -697,7 +697,7 @@ void Dolphin::paste()
 
 void Dolphin::updatePasteAction()
 {
-    KAction* pasteAction = actionCollection()->action(KStdAction::stdName(KStdAction::Paste));
+    TDEAction* pasteAction = actionCollection()->action(KStdAction::stdName(KStdAction::Paste));
     if (pasteAction == 0) {
         return;
     }
@@ -851,16 +851,16 @@ void Dolphin::showHiddenFiles()
 {
     clearStatusBar();
 
-    const KToggleAction* showHiddenFilesAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_hidden_files"));
+    const TDEToggleAction* showHiddenFilesAction =
+        static_cast<TDEToggleAction*>(actionCollection()->action("show_hidden_files"));
     const bool show = showHiddenFilesAction->isChecked();
     m_activeView->setShowHiddenFilesEnabled(show);
 }
 
 void Dolphin::showFilterBar()
 {
-    const KToggleAction* showFilterBarAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_filter_bar"));
+    const TDEToggleAction* showFilterBarAction =
+        static_cast<TDEToggleAction*>(actionCollection()->action("show_filter_bar"));
     const bool show = showFilterBarAction->isChecked();
     m_activeView->slotShowFilterBar(show);
 }
@@ -996,7 +996,7 @@ void Dolphin::editSettings()
     dlg.exec();
 }
 
-void Dolphin::addUndoOperation(KIO::Job* job)
+void Dolphin::addUndoOperation(TDEIO::Job* job)
 {
     if (job->error() != 0) {
         slotHandleJobError(job);
@@ -1066,7 +1066,7 @@ void Dolphin::addUndoOperation(KIO::Job* job)
 }
 
 Dolphin::Dolphin() :
-    KMainWindow(0, "D3lphin"),
+    TDEMainWindow(0, "D3lphin"),
     m_splitter(0),
     m_leftsidebar(0),
     m_rightsidebar(0),
@@ -1089,7 +1089,7 @@ void Dolphin::init()
 {
     // Check whether Dolphin runs the first time. If yes then
     // a proper default window size is given at the end of Dolphin::init().
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("General");
     const bool firstRun = config->readBoolEntry("First Run", true);
 
@@ -1104,7 +1104,7 @@ void Dolphin::init()
     KBookmarkGroup root = manager->root();
     if (root.first().isNull()) {
         root.addBookmark(manager, i18n("Home"), settings.homeURL(), "folder_home");
-        root.addBookmark(manager, i18n("System"), KURL("system:/"), "system");
+        root.addBookmark(manager, i18n("System"), KURL("system:/"), "computer");
         root.addBookmark(manager, i18n("Storage Media"), KURL("system:/media"), "blockdevice");
         root.addBookmark(manager, i18n("Network"), KURL("remote:/"), "network_local");
         root.addBookmark(manager, i18n("Users' Folders"), KURL("system:/users"), "folder_home2");
@@ -1164,7 +1164,7 @@ void Dolphin::loadSettings()
 {
     DolphinSettings& settings = DolphinSettings::instance();
 
-    KToggleAction* splitAction = static_cast<KToggleAction*>(actionCollection()->action("split_view"));
+    TDEToggleAction* splitAction = static_cast<TDEToggleAction*>(actionCollection()->action("split_view"));
     if (settings.isViewSplit()) {
         splitAction->setChecked(true);
         toggleSplitView();
@@ -1176,26 +1176,26 @@ void Dolphin::loadSettings()
 void Dolphin::setupActions()
 {
     // setup 'File' menu
-    KAction* createFolder = new KAction(i18n("Folder..."), "Ctrl+N",
+    TDEAction* createFolder = new TDEAction(i18n("Folder..."), "Ctrl+N",
                                         TQT_TQOBJECT(this), TQT_SLOT(createFolder()),
                                         actionCollection(), "create_folder");
     createFolder->setIcon("folder");
 
-    new KAction(i18n("Rename"), KKey(Key_F2),
+    new TDEAction(i18n("Rename"), KKey(Key_F2),
                 TQT_TQOBJECT(this), TQT_SLOT(rename()),
                 actionCollection(), "rename");
 
-    KAction* moveToTrashAction = new KAction(i18n("Move to Trash"), KKey(Key_Delete),
+    TDEAction* moveToTrashAction = new TDEAction(i18n("Move to Trash"), KKey(Key_Delete),
                                              TQT_TQOBJECT(this), TQT_SLOT(moveToTrash()),
                                              actionCollection(), "move_to_trash");
     moveToTrashAction->setIcon("edittrash");
 
-    KAction* deleteAction = new KAction(i18n("Delete"), "Shift+Delete",
+    TDEAction* deleteAction = new TDEAction(i18n("Delete"), "Shift+Delete",
                                         TQT_TQOBJECT(this), TQT_SLOT(deleteItems()),
                                         actionCollection(), "delete");
-    deleteAction->setIcon("editdelete");
+    deleteAction->setIcon("edit-delete");
 
-    new KAction(i18n("Propert&ies"), "Alt+Return",
+    new TDEAction(i18n("Propert&ies"), "Alt+Return",
                      TQT_TQOBJECT(this), TQT_SLOT(properties()),
                      actionCollection(), "properties");
 
@@ -1223,11 +1223,11 @@ void Dolphin::setupActions()
     KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(copy()), actionCollection());
     KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(paste()), actionCollection());
 
-    new KAction(i18n("Select All"), "Ctrl+A",
+    new TDEAction(i18n("Select All"), "Ctrl+A",
                 TQT_TQOBJECT(this), TQT_SLOT(selectAll()),
                 actionCollection(), "select_all");
 
-    new KAction(i18n("Invert Selection"), "Ctrl+Shift+A",
+    new TDEAction(i18n("Invert Selection"), "Ctrl+Shift+A",
                 TQT_TQOBJECT(this), TQT_SLOT(invertSelection()),
                 actionCollection(), "invert_selection");
 
@@ -1240,78 +1240,78 @@ void Dolphin::setupActions()
                         TQT_SLOT(zoomOut()),
                         actionCollection());
 
-    KRadioAction* iconsView = new KRadioAction(i18n("Icons"), "Ctrl+1",
+    TDERadioAction* iconsView = new TDERadioAction(i18n("Icons"), "Ctrl+1",
                                                 TQT_TQOBJECT(this), TQT_SLOT(setIconsView()),
                                                 actionCollection(), "icons");
     iconsView->setExclusiveGroup("view_mode");
     iconsView->setIcon("view_icon");
 
-    KRadioAction* detailsView = new KRadioAction(i18n("Details"), "Ctrl+2",
+    TDERadioAction* detailsView = new TDERadioAction(i18n("Details"), "Ctrl+2",
                                                  TQT_TQOBJECT(this), TQT_SLOT(setDetailsView()),
                                                  actionCollection(), "details");
     detailsView->setExclusiveGroup("view_mode");
     detailsView->setIcon("view_text");
 
-    KRadioAction* previewsView = new KRadioAction(i18n("Previews"), "Ctrl+3",
+    TDERadioAction* previewsView = new TDERadioAction(i18n("Previews"), "Ctrl+3",
                                                    TQT_TQOBJECT(this), TQT_SLOT(setPreviewsView()),
                                                    actionCollection(), "previews");
     previewsView->setExclusiveGroup("view_mode");
     previewsView->setIcon("gvdirpart");
 
-    KRadioAction* sortByName = new KRadioAction(i18n("By Name"), 0,
+    TDERadioAction* sortByName = new TDERadioAction(i18n("By Name"), 0,
                                                 TQT_TQOBJECT(this), TQT_SLOT(sortByName()),
                                                 actionCollection(), "by_name");
     sortByName->setExclusiveGroup("sort");
 
-    KRadioAction* sortBySize = new KRadioAction(i18n("By Size"), 0,
+    TDERadioAction* sortBySize = new TDERadioAction(i18n("By Size"), 0,
                                                 TQT_TQOBJECT(this), TQT_SLOT(sortBySize()),
                                                 actionCollection(), "by_size");
     sortBySize->setExclusiveGroup("sort");
 
-    KRadioAction* sortByDate = new KRadioAction(i18n("By Date"), 0,
+    TDERadioAction* sortByDate = new TDERadioAction(i18n("By Date"), 0,
                                                 TQT_TQOBJECT(this), TQT_SLOT(sortByDate()),
                                                 actionCollection(), "by_date");
     sortByDate->setExclusiveGroup("sort");
 
-    new KToggleAction(i18n("Descending"), 0, TQT_TQOBJECT(this), TQT_SLOT(toggleSortOrder()),
+    new TDEToggleAction(i18n("Descending"), 0, TQT_TQOBJECT(this), TQT_SLOT(toggleSortOrder()),
                       actionCollection(), "descending");
 
-    new KToggleAction(i18n("Show Hidden Files"), "Alt+.",
+    new TDEToggleAction(i18n("Show Hidden Files"), "Alt+.",
                       TQT_TQOBJECT(this), TQT_SLOT(showHiddenFiles()),
                       actionCollection(), "show_hidden_files");
 
-    KToggleAction* splitAction = new KToggleAction(i18n("Split View"), "F10",
+    TDEToggleAction* splitAction = new TDEToggleAction(i18n("Split View"), "F10",
                                                    TQT_TQOBJECT(this), TQT_SLOT(toggleSplitView()),
                                                    actionCollection(), "split_view");
     splitAction->setIcon("view_left_right");
 
-    KAction* reloadAction = new KAction(i18n("Reload"), "F5",
+    TDEAction* reloadAction = new TDEAction(i18n("Reload"), "F5",
                                         TQT_TQOBJECT(this), TQT_SLOT(reloadView()),
                                         actionCollection(), "reload");
     reloadAction->setIcon("reload");
 
-    KAction* stopAction = new KAction(i18n("Stop"), 0,
+    TDEAction* stopAction = new TDEAction(i18n("Stop"), 0,
                                       TQT_TQOBJECT(this), TQT_SLOT(stopLoading()),
                                       actionCollection(), "stop");
-    stopAction->setIcon("stop");
+    stopAction->setIcon("process-stop");
 
-    new KAction(i18n("Edit Location"), "Ctrl+L",
+    new TDEAction(i18n("Edit Location"), "Ctrl+L",
                 TQT_TQOBJECT(this), TQT_SLOT(editLocation()),
                 actionCollection(), "edit_location");
 
-    new KAction(i18n("Browse"), "Ctrl+B",
+    new TDEAction(i18n("Browse"), "Ctrl+B",
                 TQT_TQOBJECT(this), TQT_SLOT(browse()),
                 actionCollection(), "browse");
 
-    new KToggleAction(i18n("Left Sidebar"), "F8",
+    new TDEToggleAction(i18n("Left Sidebar"), "F8",
                       TQT_TQOBJECT(this), TQT_SLOT(toggleleftSidebar()),
                       actionCollection(), "leftsidebar");
                       
-    new KToggleAction(i18n("Right Sidebar"), "F9",
+    new TDEToggleAction(i18n("Right Sidebar"), "F9",
                       TQT_TQOBJECT(this), TQT_SLOT(togglerightSidebar()),
                       actionCollection(), "rightsidebar");
 
-    new KAction(i18n("Adjust View Properties..."), 0,
+    new TDEAction(i18n("Adjust View Properties..."), 0,
                 TQT_TQOBJECT(this), TQT_SLOT(adjustViewProperties()),
                 actionCollection(), "view_properties");
 
@@ -1322,21 +1322,21 @@ void Dolphin::setupActions()
     KStdAction::home(TQT_TQOBJECT(this), TQT_SLOT(goHome()), actionCollection());
 
     // setup 'Tools' menu
-    KAction* openTerminalAction = new KAction(i18n("Open Terminal"), "F4",
+    TDEAction* openTerminalAction = new TDEAction(i18n("Open Terminal"), "F4",
                                          TQT_TQOBJECT(this), TQT_SLOT(openTerminal()),
                                          actionCollection(), "open_terminal");
     openTerminalAction->setIcon("konsole");
 
-    KAction* findFileAction = new KAction(i18n("Find File..."), "Ctrl+F",
+    TDEAction* findFileAction = new TDEAction(i18n("Find File..."), "Ctrl+F",
                                          TQT_TQOBJECT(this), TQT_SLOT(findFile()),
                                          actionCollection(), "find_file");
     findFileAction->setIcon("filefind");
 
-    new KToggleAction(i18n("Show Filter Bar"), "filter", "/",
+    new TDEToggleAction(i18n("Show Filter Bar"), "filter", "/",
                       TQT_TQOBJECT(this), TQT_SLOT(showFilterBar()),
                       actionCollection(), "show_filter_bar");
 
-    KAction* compareFilesAction = new KAction(i18n("Compare Files"), 0,
+    TDEAction* compareFilesAction = new TDEAction(i18n("Compare Files"), 0,
                                           TQT_TQOBJECT(this), TQT_SLOT(compareFiles()),
                                           actionCollection(), "compare_files");
     compareFilesAction->setIcon("kompare");
@@ -1408,7 +1408,7 @@ void Dolphin::setupCreateNewMenuActions()
     KSortableValueList<CreateFileEntry, TQString>::ConstIterator end = m_createFileTemplates.end();
     while (it != end) {
         CreateFileEntry entry = (*it).value();
-        KAction* action = new KAction(entry.name);
+        TDEAction* action = new TDEAction(entry.name);
         action->setIcon(entry.icon);
         action->setName((*it).index().ascii());
         connect(action, TQT_SIGNAL(activated()),
@@ -1452,12 +1452,12 @@ void Dolphin::updateHistory()
     int index = 0;
     const TQValueList<URLNavigator::HistoryElem> list = m_activeView->urlHistory(index);
 
-    KAction* backAction = actionCollection()->action("go_back");
+    TDEAction* backAction = actionCollection()->action("go_back");
     if (backAction != 0) {
         backAction->setEnabled(index < static_cast<int>(list.count()) - 1);
     }
 
-    KAction* forwardAction = actionCollection()->action("go_forward");
+    TDEAction* forwardAction = actionCollection()->action("go_forward");
     if (forwardAction != 0) {
         forwardAction->setEnabled(index > 0);
     }
@@ -1472,7 +1472,7 @@ void Dolphin::updateEditActions()
     else {
         stateChanged("has_selection");
 
-        KAction* renameAction = actionCollection()->action("rename");
+        TDEAction* renameAction = actionCollection()->action("rename");
         if (renameAction != 0) {
             renameAction->setEnabled(list->count() >= 1);
         }
@@ -1490,7 +1490,7 @@ void Dolphin::updateEditActions()
             ++it;
         }
 
-        KAction* moveToTrashAction = actionCollection()->action("move_to_trash");
+        TDEAction* moveToTrashAction = actionCollection()->action("move_to_trash");
         moveToTrashAction->setEnabled(enableMoveToTrash);
     }
     updatePasteAction();
@@ -1498,17 +1498,17 @@ void Dolphin::updateEditActions()
 
 void Dolphin::updateViewActions()
 {
-    KAction* zoomInAction = actionCollection()->action(KStdAction::stdName(KStdAction::ZoomIn));
+    TDEAction* zoomInAction = actionCollection()->action(KStdAction::stdName(KStdAction::ZoomIn));
     if (zoomInAction != 0) {
         zoomInAction->setEnabled(m_activeView->isZoomInPossible());
     }
 
-    KAction* zoomOutAction = actionCollection()->action(KStdAction::stdName(KStdAction::ZoomOut));
+    TDEAction* zoomOutAction = actionCollection()->action(KStdAction::stdName(KStdAction::ZoomOut));
     if (zoomOutAction != 0) {
         zoomOutAction->setEnabled(m_activeView->isZoomOutPossible());
     }
 
-    KAction* action = 0;
+    TDEAction* action = 0;
     switch (m_activeView->mode()) {
         case DolphinView::IconsView:
             action = actionCollection()->action("icons");
@@ -1524,34 +1524,34 @@ void Dolphin::updateViewActions()
     }
 
     if (action != 0) {
-        KToggleAction* toggleAction = static_cast<KToggleAction*>(action);
+        TDEToggleAction* toggleAction = static_cast<TDEToggleAction*>(action);
         toggleAction->setChecked(true);
     }
 
     slotSortingChanged(m_activeView->sorting());
     slotSortOrderChanged(m_activeView->sortOrder());
 
-    KToggleAction* showFilterBarAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_filter_bar"));
+    TDEToggleAction* showFilterBarAction =
+        static_cast<TDEToggleAction*>(actionCollection()->action("show_filter_bar"));
     showFilterBarAction->setChecked(m_activeView->isFilterBarVisible());
 
-    KToggleAction* showHiddenFilesAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_hidden_files"));
+    TDEToggleAction* showHiddenFilesAction =
+        static_cast<TDEToggleAction*>(actionCollection()->action("show_hidden_files"));
     showHiddenFilesAction->setChecked(m_activeView->isShowHiddenFilesEnabled());
 
-    KToggleAction* splitAction = static_cast<KToggleAction*>(actionCollection()->action("split_view"));
+    TDEToggleAction* splitAction = static_cast<TDEToggleAction*>(actionCollection()->action("split_view"));
     splitAction->setChecked(m_view[SecondaryIdx] != 0);
 
-    KToggleAction* leftsidebarAction = static_cast<KToggleAction*>(actionCollection()->action("leftsidebar"));
+    TDEToggleAction* leftsidebarAction = static_cast<TDEToggleAction*>(actionCollection()->action("leftsidebar"));
     leftsidebarAction->setChecked(m_leftsidebar != 0);
     
-    KToggleAction* rightsidebarAction = static_cast<KToggleAction*>(actionCollection()->action("rightsidebar"));
+    TDEToggleAction* rightsidebarAction = static_cast<TDEToggleAction*>(actionCollection()->action("rightsidebar"));
     rightsidebarAction->setChecked(m_rightsidebar != 0);
 }
 
 void Dolphin::updateGoActions()
 {
-    KAction* goUpAction = actionCollection()->action(KStdAction::stdName(KStdAction::Up));
+    TDEAction* goUpAction = actionCollection()->action(KStdAction::stdName(KStdAction::Up));
     const KURL& currentURL = m_activeView->url();
     goUpAction->setEnabled(currentURL.upURL() != currentURL);
 }
@@ -1563,7 +1563,7 @@ void Dolphin::updateViewProperties(const KURL::List& urls)
     }
 
     // Updating the view properties might take up to several seconds
-    // when dragging several thousand URLs. Writing a KIO slave for this
+    // when dragging several thousand URLs. Writing a TDEIO slave for this
     // use case is not worth the effort, but at least the main widget
     // must be disabled and a progress should be shown.
     ProgressIndicator progressIndicator(i18n("Updating view properties..."),
@@ -1581,23 +1581,23 @@ void Dolphin::updateViewProperties(const KURL::List& urls)
 
 void Dolphin::copyURLs(const KURL::List& source, const KURL& dest)
 {
-    KIO::Job* job = KIO::copy(source, dest);
+    TDEIO::Job* job = TDEIO::copy(source, dest);
     addPendingUndoJob(job, DolphinCommand::Copy, source, dest);
 }
 
 void Dolphin::moveURLs(const KURL::List& source, const KURL& dest)
 {
-    KIO::Job* job = KIO::move(source, dest);
+    TDEIO::Job* job = TDEIO::move(source, dest);
     addPendingUndoJob(job, DolphinCommand::Move, source, dest);
 }
 
-void Dolphin::addPendingUndoJob(KIO::Job* job,
+void Dolphin::addPendingUndoJob(TDEIO::Job* job,
                                 DolphinCommand::Type commandType,
                                 const KURL::List& source,
                                 const KURL& dest)
 {
-    connect(job, TQT_SIGNAL(result(KIO::Job*)),
-            this, TQT_SLOT(addUndoOperation(KIO::Job*)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
+            this, TQT_SLOT(addUndoOperation(TDEIO::Job*)));
 
     UndoInfo undoInfo;
     undoInfo.id = job->progressId();
@@ -1691,7 +1691,7 @@ void Dolphin::toggleleftSidebar()
         closeleftSidebar();
     }
 
-    KToggleAction* leftsidebarAction = static_cast<KToggleAction*>(actionCollection()->action("leftsidebar"));
+    TDEToggleAction* leftsidebarAction = static_cast<TDEToggleAction*>(actionCollection()->action("leftsidebar"));
     leftsidebarAction->setChecked(m_leftsidebar != 0);
 }
 
@@ -1704,7 +1704,7 @@ void Dolphin::togglerightSidebar()
         closerightSidebar();
     }
 
-    KToggleAction* rightsidebarAction = static_cast<KToggleAction*>(actionCollection()->action("rightsidebar"));
+    TDEToggleAction* rightsidebarAction = static_cast<TDEToggleAction*>(actionCollection()->action("rightsidebar"));
     rightsidebarAction->setChecked(m_rightsidebar != 0);
 }
 
